"""Application configuration."""

import msgspec


class Settings(msgspec.Struct):
    """Application settings."""

    # Application
    APP_NAME: str = "{{ project_slug }}"
    APP_ENV: str = "development"
    DEBUG: bool = True

    # CORS
    ALLOWED_ORIGINS: list[str] = ["http://localhost:3000", "http://localhost:5173"]

    # Database
    DATABASE_URL: str = "sqlite:///./app.db"
{% block extra_settings %}
{% endblock %}


settings = Settings()
