# {{ project_name }}

{{ description }}

## Development

Created with [litestar-start](https://github.com/Harshal6927/litestar-start).

## Setup

1. Clone the repository
2. Install dependencies
3. Run the application

## License

MIT
