from litestar import Controller, get


class BaseController(Controller):
    """Base API controller."""

    path = "/api/v1"

    @get("/status")
    async def get_status(self) -> dict[str, str]:
        """Get API status."""
        return {"status": "ok"}
